==> haskell-selective-0.7.0.1-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-selective.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 selective
version:              0.7.0.1
visibility:           public
id:                   selective-0.7.0.1-CUOlDi35P8Q2Hvc6NJJHOX
key:                  selective-0.7.0.1-CUOlDi35P8Q2Hvc6NJJHOX
license:              MIT
copyright:            Andrey Mokhov, 2018-2024
maintainer:
    Andrey Mokhov <andrey.mokhov@gmail.com>, github: @snowleopard

author:
    Andrey Mokhov <andrey.mokhov@gmail.com>, github: @snowleopard

homepage:             https://github.com/snowleopard/selective
synopsis:             Selective applicative functors
description:
    Selective applicative functors: declare your effects statically,
    select which to execute dynamically.

    This is a library for /selective applicative functors/, or just
    /selective functors/ for short, an abstraction between
    applicative functors and monads, introduced in
    <https://dl.acm.org/doi/10.1145/3341694 this paper>.

category:             Control
abi:                  5c36c678ef83e4f89fae9cf7ed73d21b
exposed:              True
exposed-modules:
    Control.Selective Control.Selective.Free Control.Selective.Multi
    Control.Selective.Rigid.Free Control.Selective.Rigid.Freer
    Control.Selective.Trans.Except

import-dirs:          /usr/lib/ghc-9.4.8/site-local/selective-0.7.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/selective-0.7.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/selective-0.7.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-selective
hs-libraries:         HSselective-0.7.0.1-CUOlDi35P8Q2Hvc6NJJHOX
depends:              base-4.17.2.1 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-selective/html/selective.haddock
haddock-html:         /usr/share/doc/haskell-selective/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-selective-0.7.0.1-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-selective.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 selective
version:              0.7.0.1
visibility:           public
id:                   selective-0.7.0.1-1zV7NDWnUMcH5K7A2tTPub
key:                  selective-0.7.0.1-1zV7NDWnUMcH5K7A2tTPub
license:              MIT
copyright:            Andrey Mokhov, 2018-2024
maintainer:
    Andrey Mokhov <andrey.mokhov@gmail.com>, github: @snowleopard

author:
    Andrey Mokhov <andrey.mokhov@gmail.com>, github: @snowleopard

homepage:             https://github.com/snowleopard/selective
synopsis:             Selective applicative functors
description:
    Selective applicative functors: declare your effects statically,
    select which to execute dynamically.

    This is a library for /selective applicative functors/, or just
    /selective functors/ for short, an abstraction between
    applicative functors and monads, introduced in
    <https://dl.acm.org/doi/10.1145/3341694 this paper>.

category:             Control
abi:                  5af65ec2cccabf7fdb33890a78ff693b
exposed:              True
exposed-modules:
    Control.Selective Control.Selective.Free Control.Selective.Multi
    Control.Selective.Rigid.Free Control.Selective.Rigid.Freer
    Control.Selective.Trans.Except

import-dirs:          /usr/lib/ghc-9.4.8/site-local/selective-0.7.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/selective-0.7.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/selective-0.7.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-selective
hs-libraries:         HSselective-0.7.0.1-1zV7NDWnUMcH5K7A2tTPub
depends:              base-4.17.2.1 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-selective/html/selective.haddock
haddock-html:         /usr/share/doc/haskell-selective/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
